{% extends "wafer/nav.html" %}
{% load static from staticfiles %}

{% block navtitle %}
    <a class="navbar-brand" href="{% url 'wafer_page' %}">
        <img src="{% static "img/logo.png" %}" alt='Logo'/>
        {{ WAFER_CONFERENCE_NAME }}
    </a>
{% endblock navtitle %}
